@@ -23,6 +23,10 @@
 
 #include <limits.h>
 
+#ifndef MAX_INTERFACE_NAME_LEN
+#define MAX_INTERFACE_NAME_LEN 256
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -529,7 +533,7 @@ typedef struct {
 
 typedef struct {
     char default_gateway[SIGAR_INET6_ADDRSTRLEN];
-    char default_gateway_interface[16];
+    char default_gateway_interface[MAX_INTERFACE_NAME_LEN];
     char host_name[SIGAR_MAXHOSTNAMELEN];
     char domain_name[SIGAR_MAXDOMAINNAMELEN];
     char primary_dns[SIGAR_INET6_ADDRSTRLEN];
@@ -556,7 +560,7 @@ typedef struct {
         mtu,
         window,
         irtt;
-    char ifname[16];
+    char ifname[MAX_INTERFACE_NAME_LEN];
 } sigar_net_route_t;
 
 typedef struct {
@@ -602,7 +606,7 @@ SIGAR_DECLARE(int) sigar_net_route_list_destroy(sigar_t *sigar,
 #define SIGAR_IPV6_ADDR_COMPATv4   0x0080
 
 typedef struct {
-    char name[16];
+    char name[MAX_INTERFACE_NAME_LEN];
     char type[64];
     char description[256];
     sigar_net_address_t hwaddr;
@@ -847,7 +851,7 @@ sigar_net_listen_address_get(sigar_t *sigar,
                              sigar_net_address_t *address);
 
 typedef struct {
-    char ifname[16];
+    char ifname[MAX_INTERFACE_NAME_LEN];
     char type[64];
     sigar_net_address_t hwaddr;
     sigar_net_address_t address;
