@@ -50,8 +50,7 @@
 #endif
 #include <mach-o/dyld.h>
 #define __OPENTRANSPORTPROVIDERS__
-#include <Gestalt.h>
-#include <CFString.h>
+#include <CoreServices/CoreServices.h>
 #include <CoreFoundation/CoreFoundation.h>
 #include <IOKit/IOBSD.h>
 #include <IOKit/IOKitLib.h>
@@ -3661,6 +3660,9 @@ int sigar_os_sys_info_get(sigar_t *sigar,
           case 6:
             codename = "Snow Leopard";
             break;
+          case 7:
+            codename = "Lion";
+            break;
           default:
             codename = "Unknown";
             break;
