@@ -19,11 +19,24 @@
 #ifndef SIGAR_OS_H
 #define SIGAR_OS_H
 
-#if _MSC_VER <= 1200
-#define SIGAR_USING_MSC6 /* Visual Studio version 6 */
+#if !defined(MSVC) && defined(_MSC_VER)
+#define MSVC
 #endif
 
+#ifdef MSVC
 #define WIN32_LEAN_AND_MEAN
+#define snprintf _snprintf
+#if _MSC_VER <= 1200
+#define SIGAR_USING_MSC6 /* Visual Studio version 6 */
+#define HAVE_MIB_IPADDRROW_WTYPE 0
+#else
+#define HAVE_MIB_IPADDRROW_WTYPE 1
+#endif
+#else
+/* Cross compiling */
+#define _WIN32_WINNT 0x0501
+#endif
+
 #include <windows.h>
 #include <winreg.h>
 #include <winperf.h>
@@ -38,12 +51,27 @@
 
 #include "sigar_util.h"
 
-#define INT64_C(val) val##i64
+#ifdef MSVC
+#  define INT64_C(val) val##i64
+#  define SIGAR_DLLFUNC(api, name) \
+    struct { \
+         const char *name; \
+         ##api##_##name func; \
+    } ##name
+#else
+/* The GCC compiler doesn't require/accept the ## prefix */
+#  define INT64_C(val) val##L
+#  define SIGAR_DLLFUNC(api, name)		\
+    struct { \
+         const char *name; \
+         api##_##name func; \
+    } name
+#endif
 
 /* see apr/include/arch/win32/atime.h */
 #define EPOCH_DELTA INT64_C(11644473600000000)
 
-#define SIGAR_CMDLINE_MAX 4096
+#define SIGAR_CMDLINE_MAX 4096<<2
 
 /* XXX: support CP_UTF8 ? */
 
@@ -457,12 +485,6 @@ typedef BOOL (CALLBACK *mpr_get_net_connection)(LPCTSTR,
                                                 LPTSTR,
                                                 LPDWORD);
 
-#define SIGAR_DLLFUNC(api, name) \
-    struct { \
-         const char *name; \
-         ##api##_##name func; \
-    } ##name
-
 typedef struct {
     sigar_dll_handle_t handle;
 
@@ -567,6 +589,7 @@ struct sigar_t {
     sigar_cache_t *netif_mib_rows;
     sigar_cache_t *netif_addr_rows;
     sigar_cache_t *netif_names; /* dwIndex -> net_interface_config.name */
+    int netif_name_short;
 
     WORD ws_version;
     int ws_error;
